@@ -87,10 +87,15 @@ class FastQC():
 
         # TC: may 2020 Here we add the mean quality, which surprisingly is not
         # to be found in the basic statistics.
-        quality_sum = sum([x['quality'] * x['count'] for x in self.fastqc_data[s_name]['per_sequence_quality_scores']])
-        nreads = sum([x['count'] for x in self.fastqc_data[s_name]['per_sequence_quality_scores']])
-        mean_quality = quality_sum / float(nreads)
-        self.fastqc_data[s_name]['basic_statistics']['mean_quality'] = mean_quality
+        try:
+            quality_sum = sum([x['quality'] * x['count'] for x in self.fastqc_data[s_name]['per_sequence_quality_scores']])
+            nreads = sum([x['count'] for x in self.fastqc_data[s_name]['per_sequence_quality_scores']])
+            mean_quality = quality_sum / float(nreads)
+            self.fastqc_data[s_name]['basic_statistics']['mean_quality'] = mean_quality
+        except:
+            # if no sequence to be found; 
+            self.fastqc_data[s_name]['basic_statistics']['mean_quality'] = 0
+            self.fastqc_data[s_name]['basic_statistics']['avg_sequence_length'] = 0
 
         # Calculate the average sequence length (Basic Statistics gives a range)
         length_bp = 0
@@ -123,15 +128,16 @@ class FastQC():
         ymax = max_score + 1
         xmax = 0
         for sample in self.fastqc_data.keys():
-            data = {self._avg_bp_from_range(d['base']): d['mean']
-                for d in self.fastqc_data[sample]['per_base_sequence_quality']}
-            df = pd.Series(data)
-            df.plot(color="k", alpha=0.5)
+            if "per_sequence_quality_scores" in self.fastqc_data[sample]:
+                data = {self._avg_bp_from_range(d['base']): d['mean']
+                    for d in self.fastqc_data[sample]['per_base_sequence_quality']}
+                df = pd.Series(data)
+                df.plot(color="k", alpha=0.5)
 
-            if df.max() > ymax:
-                ymax = df.max()
-            if df.index.max() > xmax:
-                xmax = df.index.max()
+                if df.max() > ymax:
+                    ymax = df.max()
+                if df.index.max() > xmax:
+                    xmax = df.index.max()
 
         if ax:
             pylab.sca(ax)
