@@ -22,6 +22,7 @@ from jinja2 import Environment, PackageLoader
 import subprocess
 import seaborn as sns
 import matplotlib.pyplot as plt
+from itertools import combinations
 
 from sequana.lazy import pandas as pd
 from sequana.lazy import pylab
@@ -50,7 +51,13 @@ class RNADiffAnalysis:
     :param beta_prior: Default False.
     :param independent_filtering: To let DESeq2 perform the independentFiltering or not.
     :param cooks_cutoff: To let DESeq2 decide for the CooksCutoff or specifying a value.
+    :param gff: Path to the corresponding gff3 to add annotations.
+    :param fc_attribute: GFF attribute used in FeatureCounts.
+    :param fc_feature: GFF feaure used in FeatureCounts.
+    :param annot_cols: GFF attributes to use for results annotations
     :param threads: Number of threads to use
+    :param outdir: Path to output directory.
+    :param sep: The separator to use in dataframe exports
     """
 
     template_file = "rnadiff_light_template.R"
@@ -68,6 +75,10 @@ class RNADiffAnalysis:
         beta_prior=False,
         independent_filtering=True,
         cooks_cutoff=None,
+        gff=None,
+        fc_attribute=None,
+        fc_feature=None,
+        annot_cols=["ID", "Name", "gene_biotype"],
         threads=4,
         outdir="rnadiff",
         sep="\t",
@@ -76,8 +87,10 @@ class RNADiffAnalysis:
         self.counts_tsv = counts_tsv
         self.groups_tsv = groups_tsv
 
-        self.counts = pd.read_csv(counts_tsv, sep=sep, index_col="Geneid")
-        self.groups = pd.read_csv(groups_tsv, sep=sep, index_col="label")
+        self.counts = pd.read_csv(counts_tsv, sep=sep, index_col="Geneid",
+            comment="#")
+        self.groups = pd.read_csv(groups_tsv, sep=sep, index_col="label",
+            comment="#")
 
         self.condition = condition
         self.comparisons = comparisons
@@ -90,10 +103,13 @@ class RNADiffAnalysis:
         self.beta_prior = "TRUE" if beta_prior else "FALSE"
         self.independent_filtering = "TRUE" if independent_filtering else "FALSE"
         self.cooks_cutoff = cooks_cutoff if cooks_cutoff else "TRUE"
+        self.gff = gff
+        self.fc_feature = fc_feature
+        self.fc_attribute = fc_attribute
         self.threads = threads
 
         self.outdir = Path(outdir)
-        self.results = None
+        self.results = self._run()
 
     def __repr__(self):
         info = f"RNADiffAnalysis object:\n\
@@ -106,12 +122,13 @@ Groups overview:\n\
 
         return info
 
-    def run(self):
+    def _run(self):
         """Create outdir and a DESeq2 script from template for analysis. Then execute
         this script.
         """
 
-        self.outdir.mkdir()
+        try:self.outdir.mkdir()
+        except:pass
 
         with open("rnadiff_light.R", "w") as f:
             f.write(RNADiffAnalysis.template.render(self.__dict__))
@@ -128,21 +145,19 @@ Groups overview:\n\
         with open("rnadiff.out", "w") as f:
             f.write(p.stdout)
 
-    def get_results(self):
-        """Import results after run."""
-
-    def annotate(self, gff):
-        """Add annotation to deseq results (from mart or gff)
-        **IN DEV**
-        """
-        gff = GFF3(gff)
-        gff_df = gff.get_df()
-        gff_df.to_csv("test.csv")
+        return RNADiffResults2(
+            self.outdir,
+            self.groups_tsv,
+            group=self.condition,
+            gff=self.gff,
+            fc_feature=self.fc_feature,
+            fc_attribute=self.fc_attribute,
+        )
 
 
 class RNADiffTable:
-    def __init__(self, path, alpha=0.05, log2_fc=0, sep="\t"):
-        """"""
+    def __init__(self, path, gff=None, alpha=0.05, log2_fc=0, sep="\t"):
+        """ A representation of the results of a single rnadiff comparison """
         self.path = Path(path)
         self.name = self.path.name
 
@@ -222,12 +237,16 @@ class RNADiffResults2:
         self,
         rnadiff_folder,
         meta,
+        gff=None,
+        fc_attribute=None,
+        fc_feature=None,
         pattern="*vs*_degs_DESeq2.tsv",
         alpha=0.05,
         log2_fc=0,
         sep="\t",
         palette=sns.color_palette(desat=0.6),
         group="condition",
+        annot_cols=["ID", "Name", "gene_biotype"],
     ):
         """"""
         self.path = Path(rnadiff_folder)
@@ -248,13 +267,18 @@ class RNADiffResults2:
             self.path / "overall_dds.tsv", index_col=0, sep=sep
         )
 
+        self.gff = gff
+        self.fc_attribute = fc_attribute
+        self.fc_feature = fc_feature
+        self.annot_cols = annot_cols
+
         self._alpha = alpha
         self._log2_fc = log2_fc
 
-        self.results = [
-            RNADiffTable(compa, alpha=self._alpha, log2_fc=self._log2_fc)
+        self.results = {
+            compa.stem: RNADiffTable(compa, alpha=self._alpha, log2_fc=self._log2_fc)
             for compa in self.comparisons
-        ]
+        }
 
         self.df = self._get_total_df()
         self.filt_df = self._get_total_df(filtered=True)
@@ -266,10 +290,10 @@ class RNADiffResults2:
     @alpha.setter
     def alpha(self, value):
         self._alpha = value
-        self.results = [
-            RNADiffTable(compa, alpha=self._alpha, log2_fc=self._log2_fc)
+        self.results = {
+            compa.stem: RNADiffTable(compa, alpha=self._alpha, log2_fc=self._log2_fc)
             for compa in self.comparisons
-        ]
+        }
         self.filt_df = self._get_total_df(filtered=True)
 
     @property
@@ -279,28 +303,48 @@ class RNADiffResults2:
     @log2_fc.setter
     def log2_fc(self, value):
         self._log2_fc = value
-        self.results = [
-            RNADiffTable(compa, alpha=self._alpha, log2_fc=self._log2_fc)
+        self.results = {
+            compa.stem: RNADiffTable(compa, alpha=self._alpha, log2_fc=self._log2_fc)
             for compa in self.comparisons
-        ]
+        }
         self.filt_df = self._get_total_df(filtered=True)
 
+    def _get_annot(self):
+        """Get a properly formatted dataframe from the gff."""
+
+        df = GFF3(self.gff).get_df()
+        df.set_index(self.fc_feature, inplace=True)
+        df = df.query("type == @self.fc_attribute").loc[:, self.annot_cols]
+        df.columns = pd.MultiIndex.from_product([["annotation"], df.columns])
+
+        return df
+
     def _get_total_df(self, filtered=False):
         """Concatenate all rnadiff results in a single dataframe."""
 
         dfs = []
 
-        for res in self.results:
+        for compa, res in self.results.items():
             df = res.filt_df if filtered else res.df
             df = df.transpose().reset_index()
             df["file"] = res.name
             df = df.set_index(["file", "index"])
             dfs.append(df)
 
-        return pd.concat(dfs, sort=True)
+        df = pd.concat(dfs, sort=True).transpose()
+
+        if self.gff and self.fc_attribute and self.fc_feature:
+            annot = self._get_annot()
+            df = pd.concat([annot, df], axis=1)
+        else:
+            logger.warning(
+                "Missing any of gff, fc_attribute or fc_feature. No annotation will be added."
+            )
+
+        return df
 
     def summary(self):
-        return pd.concat(res.summary() for res in self.results)
+        return pd.concat(res.summary() for compa, res in self.results.items())
 
     def _get_meta(self, meta_file, sep, group, palette):
         """Import metadata from a table file and add color groups following the
@@ -318,6 +362,44 @@ class RNADiffResults2:
         plt.xlabel(xlabel)
         plt.ylabel(ylabel)
 
+    def get_specific_commons(self, direction, compas=None):
+        """From all the comparisons contained by the object, extract gene lists which
+        are common (but specific, ie a gene appear in a single list) comparing
+        all combinations of comparisons.
+
+        :param direction: The regulation direction (up, down or all) of the gene
+        lists to consider
+
+        :param compas: Specify a list of comparisons to consider (Comparisons
+        names can be found with self.results.keys()).
+        """
+
+        common_specific_dict = {}
+
+        if not compas:
+            compas = self.results.keys()
+
+        for size in range(1, len(compas)):
+            for compa_group in combinations(compas, size):
+                gene_lists = [
+                    self.results[compa].gene_lists[direction] for compa in compa_group
+                ]
+                commons = set.intersection(
+                    *[set(gene_list) for gene_list in gene_lists]
+                )
+
+                other_compas = [compa for compa in compas if compa not in compa_group]
+                genes_in_other_compas = {
+                    x
+                    for other_compa in other_compas
+                    for x in self.results[other_compa].gene_lists[direction]
+                }
+
+                commons = commons - genes_in_other_compas
+                common_specific_dict[compa_group] = commons
+
+        return common_specific_dict
+
     def plot_count_per_sample(self):
         """Number of mapped and annotated reads (i.e. counts) per sample. Each color
         for each replicate
@@ -357,11 +439,9 @@ class RNADiffResults2:
             ylabel="% of null counts",
         )
 
-    def plot_pca(self, n_components=2, colors=None, plotly=False):
-        """
-        IN DEV ! NOT FUNCTIONNAL
+    def plot_pca(self, n_components=2, colors=None, plotly=False, max_features=500):
 
-        TO VERIFY that colors/names indeces actually correspond !!!
+        """
 
         .. plot::
             :include-source:
@@ -386,7 +466,12 @@ class RNADiffResults2:
         p = PCA(self.counts_vst)
         if plotly is True:
             assert n_components == 3
-            variance = p.plot(n_components=n_components, colors=colors, show_plot=False)
+            variance = p.plot(
+                n_components=n_components,
+                colors=colors,
+                show_plot=False,
+                max_features=max_features,
+            )
             from plotly import express as px
 
             df = pd.DataFrame(p.Xr)
@@ -411,7 +496,11 @@ class RNADiffResults2:
             )
             return fig
         else:
-            variance = p.plot(n_components=n_components, colors=self.meta.group_color)
+            variance = p.plot(
+                n_components=n_components,
+                colors=self.meta.group_color,
+                max_features=max_features,
+            )
 
         return variance
 
@@ -596,7 +685,13 @@ class RNADiffResults:
     """An object representation of results coming from a RNADiff analysis."""
 
     def __init__(
-        self, filename, alpha=0.05, log2_fc=0, pattern="*complete*xls", sep="\t"
+        self,
+        filename,
+        alpha=0.05,
+        log2_fc=0,
+        pattern="*complete*xls",
+        sep="\t",
+        annotations="annotations.csv",
     ):
         """.. rubric:: constructor
 
@@ -606,7 +701,6 @@ class RNADiffResults:
         :param out_dir:
         :param log2_fc: the log2 fold change to apply
 
-
         Note that if the index or Name/ID columns are made of ensemble ID, they
         may be preceded by the gene: prefix, which is removed
         """
@@ -661,6 +755,60 @@ class RNADiffResults:
 
         self._set_gene_lists_one_condition()
 
+        self.read_annotations(annotations)
+
+    def read_annotations(self, annotation_file):
+        if os.path.exists(annotation_file):
+            annot = pd.read_csv(annotation_file)
+
+            if "locus_tag" in annot.columns and len(
+                set(self.df.index).intersection(annot.locus_tag)
+            ) == len(self.df.index):
+                key = "locus_tag"
+            elif "Name" in annot.columns and len(
+                set(self.df.index).intersection(annot.Name)
+            ) == len(self.df.index):
+                key = "Name"
+            elif "gene_id" in annot.columns and len(
+                set(self.df.index).intersection(annot.gene_id)
+            ) == len(self.df.index):
+                key = "gene_id"
+            elif "ID" in annot.columns and len(
+                set(self.df.index).intersection(annot.ID)
+            ) == len(self.df.index):
+                key = "ID"
+            elif 'gene' in annot.columns and\
+                len(set(self.df.index).intersection(annot.gene)) == len(self.df.index):
+                key = "gene"
+            else:
+                logger.critical(
+                    "Could not find a key to match annotation and DGE result"
+                )
+                return
+
+            # set index and restrict to the DGE entries only
+            annot = annot.set_index(key)
+            annot = annot.loc[self.df.index]
+            # some index may have duplicates, that need to be removed
+            annot = annot.reset_index().drop_duplicates(subset=[key]).set_index(key)
+
+            # if there are missing ones, we add NA
+
+            # now add interesting columns
+            for col in ['locus_tag', 'gene_id', 'ID', 'Name', 'gene', 'gene_biotype']:
+                if col == key:
+                    continue
+                if col in annot.columns and col not in self.df.columns:
+                    try:self.df.insert(1, col, annot[col].dropna())
+                    except Exception as err:
+                        print(err)
+        else:
+            logger.warning(
+                "annotation file {} does not exists. Skipping extra annotation in final report".format(
+                    annotation_file
+                )
+            )
+
     def set_colors(self, colors=None):
         self.colors = {}
         if colors is None:
@@ -833,16 +981,16 @@ class RNADiffResults:
 
             df = self.df.copy()
             df["log_adj_pvalue"] = -pylab.log10(self.df.padj)
-            df["significance"] = ["<0.05" if x else ">=0.05" for x in df.padj < 0.05]
+            df["significance"] = ["<{}".format(padj) if x else ">={}".format(padj) for x in df.padj < padj]
 
             if "Name" in self.df.columns:
                 hover_name = "Name"
             elif "gene_id" in self.df.columns:
                 hover_name = "gene_id"
-            elif "ID" in self.df.columns:
-                hover_name = "ID"
             elif "locus_tag" in self.df.columns:
                 hover_name = "locus_tag"
+            elif "ID" in self.df.columns:
+                hover_name = "ID"
             else:
                 hover_name = None
             fig = px.scatter(
@@ -855,6 +1003,21 @@ class RNADiffResults:
                 height=600,
                 labels={"log_adj_pvalue": "log adjusted p-value"},
             )
+            #axes[0].axhline(
+            # -np.log10(0.05), lw=2, ls="--", color="r", label="pvalue threshold (0.05)"
+            #i)
+            # in future version of plotly, a add_hlines will be available. For
+            # now, this is the only way to add axhline
+            fig.update_layout(
+                shapes=[dict(type='line', 
+                              xref='x', x0=df.log2FoldChange.min(), x1=df.log2FoldChange.max(), 
+                              yref='y', y0=-pylab.log10(padj), y1=-pylab.log10(padj), 
+                            line=dict(
+                                 color="black",
+                                 width=1,
+                                 dash="dash"))
+                       ])
+
 
             return fig
 
@@ -916,7 +1079,7 @@ class RNADiffResults:
         )
         return bax
 
-    def plot_pca(self, n_components=2, colors=None, plotly=False):
+    def plot_pca(self, n_components=2, colors=None, plotly=False, max_features=500):
         """
 
         .. plot::
@@ -948,7 +1111,12 @@ class RNADiffResults:
 
         if plotly is True:
             assert n_components == 3
-            variance = p.plot(n_components=n_components, colors=colors, show_plot=False)
+            variance = p.plot(
+                n_components=n_components,
+                colors=colors,
+                show_plot=False,
+                max_features=max_features,
+            )
             from plotly import express as px
 
             df = pd.DataFrame(p.Xr)
@@ -975,7 +1143,9 @@ class RNADiffResults:
             )
             return fig
         else:
-            variance = p.plot(n_components=n_components, colors=colors)
+            variance = p.plot(
+                n_components=n_components, colors=colors, max_features=max_features
+            )
 
         return variance
 
@@ -1006,7 +1176,7 @@ class RNADiffResults:
             candidates = [
                 x
                 for x in self.condition_names
-                if re.findall(r"^{}\d+".format(x), sample_name)
+                if re.findall(r"^{}\d+$".format(x), sample_name)
             ]
             if len(candidates) == 1:
                 return candidates[0]
@@ -1070,6 +1240,10 @@ class RNADiffResults:
         pylab.yticks(range(N), self.sample_names)
         pylab.xlabel("Reads captured by most important feature (%s)")
         pylab.ylabel("Sample")
+        try:
+            pylab.tight_layout()
+        except:
+            pass
 
     def plot_dendogram(
         self,
