@@ -155,7 +155,8 @@ def samplesheet(**kwargs):
 @click.argument("name", type=click.Path(exists=True), nargs=-1)
 @click.option("--module",
     required=False,
-    type=click.Choice(["rnadiff", "bamqc", "bam", "enrichment", "fasta", "fastq"]))
+    type=click.Choice(["rnadiff", "bamqc", "bam", "enrichment", "fasta",
+        "fastq", "gff"]))
 @click.option("--enrichment-taxon", type=click.INT,
     #required=True,
     default=0,
@@ -201,6 +202,9 @@ command""")
 @click.option("--enrichment-kegg-background", type=click.INT,
     default=None,
     help="""a background for kegg enrichment. If None, set to number of genes found in KEGG""")
+@click.option("--rnadiff-annotation", type=click.Path(),
+    default=None,
+    help="""The GFF file used to perform the annotation""")
 @common_logger
 def summary(**kwargs):
     """Create a HTML report for various sequana out
@@ -223,6 +227,21 @@ def summary(**kwargs):
             --enrichment-log2-foldchange-cutoff 2 --enrichment-kegg-only
             --enrichment-kegg-pathways-directory kegg_pathways
 
+    For the RNADIFF module::
+
+        sequana summary --module rnadiff \
+            --rnadiff-annotation final_annotation.gff `ls ./tables/B4239-v2.*.complete.xls`
+
+    This will process all files in the given pattern (in back quots)
+    sequentially and procude one HTML file per input file.
+
+
+    Other module all work in the same way. For example, for FastQ files::
+
+        sequana summary one_input.fastq
+        sequana summary `ls *fastq` 
+
+
     """
     names = kwargs['name']
     module = kwargs['module']
@@ -232,6 +251,8 @@ def summary(**kwargs):
             module = "fastq"
         elif  names[0].endswith('.bam'):
             module = "bam"
+        elif  names[0].endswith('.gff') or names[0].endswith('gff3'):
+            module = "gff"
         elif names[0].endswith('fasta.gz') or names[0].endswith('.fasta'):
             module = "fasta"
         else:
@@ -252,6 +273,11 @@ def summary(**kwargs):
             else:
                 output_filename = name + ".html"
             output_filename = output_filename.split("/")[-1]
+
+            if kwargs['rnadiff_annotation']:
+                logger.info(f"Processing annoation file into annotations.csv")
+                from sequana import GFF3
+                GFF3(kwargs['rnadiff_annotation']).save_annotation_to_csv()
             logger.info(f"Processing {name} into {output_filename}")
             data = RNADiffResults(name)
             report = RNAdiffModule(data, output_filename)
@@ -303,7 +329,7 @@ def summary(**kwargs):
             ff = FastQC(filename, max_sample=1e6, verbose=False)
             stats = ff.get_stats()
             print(stats)
-    elif module == "bam": 
+    elif module == "bam":
         import pandas as pd
         from sequana import BAM
         for filename in names:
@@ -311,7 +337,16 @@ def summary(**kwargs):
             stats = ff.get_stats()
             df = pd.Series(stats).to_frame().T
             print(df)
-
+    elif module == "gff":
+        import pandas as pd
+        from sequana import GFF3
+        for filename in names:
+            ff = GFF3(filename)
+            print("#filename: {}".format(filename))
+            print("#Number of entries per genetic type:")
+            print(ff.get_df().value_counts('type').to_string())
+            print("#Number of duplicated attribute (if any) per attribute:")
+            ff.get_duplicated_attributes_per_type()
 
 
 
