@@ -122,7 +122,7 @@ class SnakeMakeStats(object):
         pylab.xlabel("Seconds (s)", fontsize=fontsize)
         try:
             pylab.tight_layout()
-        except:
+        except:  #pragma: no cover
             pass
 
     def plot_and_save(self, filename="snakemake_stats.png",
@@ -936,8 +936,11 @@ class PipelineManagerBase(object):
             namespace['expected_output'] = []
             namespace['toclean'] = []
 
-        # check requirements
-        Module(self.name).check(mode)
+        try:
+            # check requirements if possible
+            Module(self.name).check(mode)
+        except:
+            pass
 
         if matplotlib:
             import matplotlib as mpl
@@ -1878,12 +1881,14 @@ class OnSuccessCleaner(object):
             "cluster_config.json",
             "slurm*out",
             "stats.txt",
+            "unlock.sh",
             "schema.yaml"]
         if pipeline_name:
             self.files_to_remove.append("{}.sh".format(pipeline_name))
             self.files_to_remove.append("{}.rules".format(pipeline_name))
         self.directories_to_remove = [".snakemake"]
         self.bundle = bundle
+        self.custom_commands = ""
 
     def add_bundle(self, input="*", output="bundle.tar.gz"):
         self.bundle = True
@@ -1895,7 +1900,7 @@ class OnSuccessCleaner(object):
         if self.bundle:
             makefile += "bundle:\n\ttar cvfz {} {}\n".format(
                 self.bundle_output, self.bundle_input)
-        makefile += "clean: clean_files clean_directories\n"
+        makefile += "clean: clean_files clean_directories custom\n"
 
         files = self.files_to_remove + [self.makefile_filename]
         # in case commas are added in the config file
@@ -1906,6 +1911,9 @@ class OnSuccessCleaner(object):
         dirs = self.directories_to_remove
         makefile += "clean_directories:\n\trm -rf {}\n".format(" ".join(dirs))
 
+        # custom commands
+        makefile += "custom:\n\t{}\n".format(self.custom_commands)
+
         with open(self.makefile_filename, "w") as fh:
             fh.write(makefile)
 
@@ -1946,7 +1954,7 @@ def get_pipeline_statistics():
     return df
 
 
-def clean_multiqc(filename):
+'''def clean_multiqc(filename):
     print("Deprecated. Use the pipeline manager instead")
     with open(filename, "r") as fin:
         with open(filename + "_tmp_", "w") as fout:
@@ -1960,4 +1968,4 @@ def clean_multiqc(filename):
                 line = fin.readline() # read the next line
     import shutil
     shutil.move(filename +"_tmp_", filename)
-
+'''
